@@ -1,9 +1,11 @@
 import json
+from functools import partial
 
+import anyio
 import typer
 
 from . import get_abuse_contacts
-from .errors import InvalidAddressError
+from .errors import InvalidAddressError, TimeoutError
 
 app = typer.Typer()
 
@@ -13,9 +15,9 @@ def whois(
     address: str = typer.Argument(..., help="URL, domain, IP address or email address")
 ):
     try:
-        contacts = get_abuse_contacts(address)
+        contacts = anyio.run(partial(get_abuse_contacts, address))
         print(contacts.json(by_alias=True))  # noqa: T001
-    except InvalidAddressError as e:
+    except (InvalidAddressError, TimeoutError) as e:
         print(json.dumps({"error": str(e)}))  # noqa: T001
 
 
